# SeSo
**A Search and Sort Extension Module for Python**

## Install

```pip3 install seso```

## Tests

```python3 -m unittest discover tests```

## List of Algorithms

- Search
    - linear search
    - binary search
    - jump search
    - interpolation search
    - exponential search
    - fibonacci search
    - ternary search

- Sort
    - bubble sort
    - selection sort
    - insertion sort
    - merge sort
    - quick sort
    - heap sort
    - radix sort
    - bucket sort
    - shell sort
    - tim sort

## [Documentation](https://github.com/AjithRamachandran/seso/tree/main/docs)

<br />
